@@ -1,5 +1,6 @@
 # Copyright Cloudinary
 
+import datetime
 import email.utils
 import json
 import socket
@@ -31,7 +32,26 @@ def ping(**options):
 
 
 def usage(**options):
-    return call_api("get", ["usage"], {}, **options)
+    """Get account usage details.
+
+    Get a report on the status of your Cloudinary account usage details, including storage, credits, bandwidth,
+    requests, number of resources, and add-on usage. Note that numbers are updated periodically.
+
+    See: `Get account usage details
+    <https://cloudinary.com/documentation/admin_api#get_account_usage_details>`_
+
+    :param options:     Additional options
+    :type options:      dict, optional
+    :return:            Detailed usage information
+    :rtype:             Response
+    """
+    date = options.pop("date", None)
+    uri = ["usage"]
+    if date:
+        if isinstance(date, datetime.date):
+            date = utils.encode_date_to_usage_api_format(date)
+        uri.append(date)
+    return call_api("get", uri, {}, **options)
 
 
 def resource_types(**options):
@@ -104,7 +124,8 @@ def resource(public_id, **options):
     upload_type = options.pop("type", "upload")
     uri = ["resources", resource_type, upload_type, public_id]
     params = only(options, "exif", "faces", "colors", "image_metadata", "cinemagraph_analysis",
-                  "pages", "phash", "coordinates", "max_results", "quality_analysis", "derived_next_cursor")
+                  "pages", "phash", "coordinates", "max_results", "quality_analysis", "derived_next_cursor",
+                  "accessibility_analysis", "versions")
     return call_api("get", uri, params, **options)
 
 
@@ -334,8 +355,8 @@ def restore(public_ids, **options):
     resource_type = options.pop("resource_type", "image")
     upload_type = options.pop("type", "upload")
     uri = ["resources", resource_type, upload_type, "restore"]
-    params = dict(public_ids=public_ids)
-    return call_api("post", uri, params, **options)
+    params = dict(public_ids=public_ids, **only(options, "versions"))
+    return call_json_api("post", uri, params, **options)
 
 
 def upload_mappings(**options):
